@@ -22,15 +22,6 @@ class Map(Enum):
                 True,
                 True,
                 None)
-    Four_Seasons = (4,
-                    {Language.English: 'Four Seasons', Language.Korean: '사계절'},
-                    "FOUR_SEASONS",
-                    Developer.Luminous,
-                    ["Base.SC2Data/GameData/Terrain/FourSeasons.xml"],
-                    "maps/four_seasons.SC2Map",
-                    True,
-                    True,
-                    None)
     Zerus_Volcanoes = (2,
                        {Language.English: 'Zerus Volcanoes', Language.Korean: '제루스 화산'},
                        "ZERUS_VOLCANOES",
@@ -38,7 +29,7 @@ class Map(Enum):
                        ["Base.SC2Data/GameData/Terrain/ZerusVolcanoes.xml"],
                        "maps/zerus_volcanoes.SC2Map",
                        True,
-                       False,
+                       True,
                        None)
     Ruins_Of_Imladoon = (3,
                          {Language.English: 'Ruins of Imladoon', Language.Korean: '임라둔의 잔해'},
@@ -49,6 +40,15 @@ class Map(Enum):
                          True,
                          True,
                          Developer.Templar)
+    Four_Seasons = (4,
+                    {Language.English: 'Four Seasons', Language.Korean: '사계절'},
+                    "FOUR_SEASONS",
+                    Developer.Luminous,
+                    ["Base.SC2Data/GameData/Terrain/FourSeasons.xml"],
+                    "maps/four_seasons.SC2Map",
+                    False,
+                    False,
+                    None)
     Heart_Of_Amethyst = (5,
                          {Language.English: 'Heart of Amethyst', Language.Korean: '자수정의 심장'},
                          "HEART_OF_AMETHYST",
@@ -82,6 +82,15 @@ class Map(Enum):
                      Developer.Understudy,
                      ["Base.SC2Data/GameData/Terrain/KaldirCliffs.xml"],
                      "maps/kaldir_cliffs.SC2Map",
+                     False,
+                     False,
+                     None)
+    Lost_Tides = (9,
+                     {Language.English: 'Kaldir Cliffs', Language.Korean: '사라진 물의 흐름'},
+                     "LOST_TIDES",
+                     Developer.Templar,
+                     ["Base.SC2Data/GameData/Terrain/LostTides.xml"],
+                     "maps/lost_tides.SC2Map",
                      True,
                      True,
                      None)
